@@ -1,11 +1,12 @@
-from gbmgeometry.gbm import GBM#, get_legal_pairs
+from gbmgeometry.gbm import GBM  # , get_legal_pairs
 from gbmgeometry.gbm_detector import BGO0, BGO1
 from gbmgeometry.gbm_detector import NaI0, NaI1, NaI2, NaI3, NaI4, NaI5
 from gbmgeometry.gbm_detector import NaI6, NaI7, NaI8, NaI9, NaIA, NaIB
 from gbmgeometry.gbm_frame import GBMFrame
 from gbmgeometry.position_interpolator import PositionInterpolator
 from gbmgeometry.spacecraft.fermi import Fermi
-
+from gbmgeometry.utils.file_converters import convert_poshist2hdf5, convert_trigdat2hdf5
+from gbmgeometry.utils.plotting.space_plot import plot_in_space, animate_in_space
 
 gbm_detector_list = {
     "n0": NaI0,
@@ -28,6 +29,8 @@ gbm_detector_list = {
 from gbmgeometry.utils.gbm_time import GBMTime
 
 __all__ = [
+    "plot_in_space",
+    "animate_in_space",
     "GBMFrame",
     "GBM",
     "NaI0",
@@ -44,13 +47,16 @@ __all__ = [
     "NaIB",
     "BGO0",
     "BGO1",
+    "convert_poshist2hdf5",
+    "convert_trigdat2hdf5",
     "PositionInterpolator",
-#    "get_legal_pairs",
+    #    "get_legal_pairs",
     "Fermi",
     "GBMTime",
     "gbm_detector_list",
 ]
 
 from ._version import get_versions
-__version__ = get_versions()['version']
+
+__version__ = get_versions()["version"]
 del get_versions
